from setuptools import setup

setup(
    name="adaptlm",
    version="0.0.1",
    url="http://github.com/vietanhdev/adaptlm",
    license="MIT",
    author="Viet Anh Nguyen",
    author_email="vietanh.dev@gmail.com",
    description="Easy library for adapting and optimizing large models for production on specific domains",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
)
